Class: Google::Cloud::Bigquery::Migration::V2::AssessmentTaskDetails

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/bigquery/migration/v2/assessment_task.rb

Overview

Assessment task config.

Instance Attribute Summary collapse

Instance Attribute Details

#data_source::String

Returns Required. The data source or data warehouse type (eg: TERADATA/REDSHIFT) from which the input data is extracted.

Returns:

  • (::String)

    Required. The data source or data warehouse type (eg: TERADATA/REDSHIFT) from which the input data is extracted.



43
44
45
46
# File 'proto_docs/google/cloud/bigquery/migration/v2/assessment_task.rb', line 43

class AssessmentTaskDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#feature_handle::Google::Cloud::Bigquery::Migration::V2::AssessmentFeatureHandle

Returns Optional. A collection of additional feature flags for this assessment.

Returns:



43
44
45
46
# File 'proto_docs/google/cloud/bigquery/migration/v2/assessment_task.rb', line 43

class AssessmentTaskDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#input_path::String

Returns Required. The Cloud Storage path for assessment input files.

Returns:

  • (::String)

    Required. The Cloud Storage path for assessment input files.



43
44
45
46
# File 'proto_docs/google/cloud/bigquery/migration/v2/assessment_task.rb', line 43

class AssessmentTaskDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#output_dataset::String

Returns Required. The BigQuery dataset for output.

Returns:

  • (::String)

    Required. The BigQuery dataset for output.



43
44
45
46
# File 'proto_docs/google/cloud/bigquery/migration/v2/assessment_task.rb', line 43

class AssessmentTaskDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#querylogs_path::String

Returns Optional. An optional Cloud Storage path to write the query logs (which is then used as an input path on the translation task).

Returns:

  • (::String)

    Optional. An optional Cloud Storage path to write the query logs (which is then used as an input path on the translation task)



43
44
45
46
# File 'proto_docs/google/cloud/bigquery/migration/v2/assessment_task.rb', line 43

class AssessmentTaskDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end