Class: Google::Cloud::Bigquery::Migration::V2::Dialect
- Inherits:
-
Object
- Object
- Google::Cloud::Bigquery::Migration::V2::Dialect
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb
Overview
The possible dialect options for translation.
Instance Attribute Summary collapse
-
#azure_synapse_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::AzureSynapseDialect
The Azure Synapse dialect.
-
#bigquery_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::BigQueryDialect
The BigQuery dialect.
-
#db2_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::DB2Dialect
DB2 dialect.
-
#greenplum_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::GreenplumDialect
Greenplum dialect.
-
#hiveql_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::HiveQLDialect
The HiveQL dialect.
-
#mysql_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::MySQLDialect
The MySQL dialect.
-
#netezza_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::NetezzaDialect
The Netezza dialect.
-
#oracle_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::OracleDialect
The Oracle dialect.
-
#postgresql_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::PostgresqlDialect
The Postgresql dialect.
-
#presto_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::PrestoDialect
The Presto dialect.
-
#redshift_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::RedshiftDialect
The Redshift dialect.
-
#snowflake_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::SnowflakeDialect
The Snowflake dialect.
-
#sparksql_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::SparkSQLDialect
The SparkSQL dialect.
-
#sql_server_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::SQLServerDialect
The SQL Server dialect.
-
#sqlite_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::SQLiteDialect
SQLite dialect.
-
#teradata_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::TeradataDialect
The Teradata dialect.
-
#vertica_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::VerticaDialect
The Vertica dialect.
Instance Attribute Details
#azure_synapse_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::AzureSynapseDialect
Returns The Azure Synapse dialect
Note: The following fields are mutually exclusive: azure_synapse_dialect, bigquery_dialect, hiveql_dialect, redshift_dialect, teradata_dialect, oracle_dialect, sparksql_dialect, snowflake_dialect, netezza_dialect, vertica_dialect, sql_server_dialect, postgresql_dialect, presto_dialect, mysql_dialect, db2_dialect, sqlite_dialect, greenplum_dialect. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb', line 145 class Dialect include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#bigquery_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::BigQueryDialect
Returns The BigQuery dialect
Note: The following fields are mutually exclusive: bigquery_dialect, hiveql_dialect, redshift_dialect, teradata_dialect, oracle_dialect, sparksql_dialect, snowflake_dialect, netezza_dialect, azure_synapse_dialect, vertica_dialect, sql_server_dialect, postgresql_dialect, presto_dialect, mysql_dialect, db2_dialect, sqlite_dialect, greenplum_dialect. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb', line 145 class Dialect include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#db2_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::DB2Dialect
Returns DB2 dialect
Note: The following fields are mutually exclusive: db2_dialect, bigquery_dialect, hiveql_dialect, redshift_dialect, teradata_dialect, oracle_dialect, sparksql_dialect, snowflake_dialect, netezza_dialect, azure_synapse_dialect, vertica_dialect, sql_server_dialect, postgresql_dialect, presto_dialect, mysql_dialect, sqlite_dialect, greenplum_dialect. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb', line 145 class Dialect include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#greenplum_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::GreenplumDialect
Returns Greenplum dialect
Note: The following fields are mutually exclusive: greenplum_dialect, bigquery_dialect, hiveql_dialect, redshift_dialect, teradata_dialect, oracle_dialect, sparksql_dialect, snowflake_dialect, netezza_dialect, azure_synapse_dialect, vertica_dialect, sql_server_dialect, postgresql_dialect, presto_dialect, mysql_dialect, db2_dialect, sqlite_dialect. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb', line 145 class Dialect include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#hiveql_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::HiveQLDialect
Returns The HiveQL dialect
Note: The following fields are mutually exclusive: hiveql_dialect, bigquery_dialect, redshift_dialect, teradata_dialect, oracle_dialect, sparksql_dialect, snowflake_dialect, netezza_dialect, azure_synapse_dialect, vertica_dialect, sql_server_dialect, postgresql_dialect, presto_dialect, mysql_dialect, db2_dialect, sqlite_dialect, greenplum_dialect. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb', line 145 class Dialect include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#mysql_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::MySQLDialect
Returns The MySQL dialect
Note: The following fields are mutually exclusive: mysql_dialect, bigquery_dialect, hiveql_dialect, redshift_dialect, teradata_dialect, oracle_dialect, sparksql_dialect, snowflake_dialect, netezza_dialect, azure_synapse_dialect, vertica_dialect, sql_server_dialect, postgresql_dialect, presto_dialect, db2_dialect, sqlite_dialect, greenplum_dialect. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb', line 145 class Dialect include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#netezza_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::NetezzaDialect
Returns The Netezza dialect
Note: The following fields are mutually exclusive: netezza_dialect, bigquery_dialect, hiveql_dialect, redshift_dialect, teradata_dialect, oracle_dialect, sparksql_dialect, snowflake_dialect, azure_synapse_dialect, vertica_dialect, sql_server_dialect, postgresql_dialect, presto_dialect, mysql_dialect, db2_dialect, sqlite_dialect, greenplum_dialect. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb', line 145 class Dialect include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#oracle_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::OracleDialect
Returns The Oracle dialect
Note: The following fields are mutually exclusive: oracle_dialect, bigquery_dialect, hiveql_dialect, redshift_dialect, teradata_dialect, sparksql_dialect, snowflake_dialect, netezza_dialect, azure_synapse_dialect, vertica_dialect, sql_server_dialect, postgresql_dialect, presto_dialect, mysql_dialect, db2_dialect, sqlite_dialect, greenplum_dialect. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb', line 145 class Dialect include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#postgresql_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::PostgresqlDialect
Returns The Postgresql dialect
Note: The following fields are mutually exclusive: postgresql_dialect, bigquery_dialect, hiveql_dialect, redshift_dialect, teradata_dialect, oracle_dialect, sparksql_dialect, snowflake_dialect, netezza_dialect, azure_synapse_dialect, vertica_dialect, sql_server_dialect, presto_dialect, mysql_dialect, db2_dialect, sqlite_dialect, greenplum_dialect. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb', line 145 class Dialect include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#presto_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::PrestoDialect
Returns The Presto dialect
Note: The following fields are mutually exclusive: presto_dialect, bigquery_dialect, hiveql_dialect, redshift_dialect, teradata_dialect, oracle_dialect, sparksql_dialect, snowflake_dialect, netezza_dialect, azure_synapse_dialect, vertica_dialect, sql_server_dialect, postgresql_dialect, mysql_dialect, db2_dialect, sqlite_dialect, greenplum_dialect. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb', line 145 class Dialect include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#redshift_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::RedshiftDialect
Returns The Redshift dialect
Note: The following fields are mutually exclusive: redshift_dialect, bigquery_dialect, hiveql_dialect, teradata_dialect, oracle_dialect, sparksql_dialect, snowflake_dialect, netezza_dialect, azure_synapse_dialect, vertica_dialect, sql_server_dialect, postgresql_dialect, presto_dialect, mysql_dialect, db2_dialect, sqlite_dialect, greenplum_dialect. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb', line 145 class Dialect include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#snowflake_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::SnowflakeDialect
Returns The Snowflake dialect
Note: The following fields are mutually exclusive: snowflake_dialect, bigquery_dialect, hiveql_dialect, redshift_dialect, teradata_dialect, oracle_dialect, sparksql_dialect, netezza_dialect, azure_synapse_dialect, vertica_dialect, sql_server_dialect, postgresql_dialect, presto_dialect, mysql_dialect, db2_dialect, sqlite_dialect, greenplum_dialect. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb', line 145 class Dialect include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sparksql_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::SparkSQLDialect
Returns The SparkSQL dialect
Note: The following fields are mutually exclusive: sparksql_dialect, bigquery_dialect, hiveql_dialect, redshift_dialect, teradata_dialect, oracle_dialect, snowflake_dialect, netezza_dialect, azure_synapse_dialect, vertica_dialect, sql_server_dialect, postgresql_dialect, presto_dialect, mysql_dialect, db2_dialect, sqlite_dialect, greenplum_dialect. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb', line 145 class Dialect include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sql_server_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::SQLServerDialect
Returns The SQL Server dialect
Note: The following fields are mutually exclusive: sql_server_dialect, bigquery_dialect, hiveql_dialect, redshift_dialect, teradata_dialect, oracle_dialect, sparksql_dialect, snowflake_dialect, netezza_dialect, azure_synapse_dialect, vertica_dialect, postgresql_dialect, presto_dialect, mysql_dialect, db2_dialect, sqlite_dialect, greenplum_dialect. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb', line 145 class Dialect include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sqlite_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::SQLiteDialect
Returns SQLite dialect
Note: The following fields are mutually exclusive: sqlite_dialect, bigquery_dialect, hiveql_dialect, redshift_dialect, teradata_dialect, oracle_dialect, sparksql_dialect, snowflake_dialect, netezza_dialect, azure_synapse_dialect, vertica_dialect, sql_server_dialect, postgresql_dialect, presto_dialect, mysql_dialect, db2_dialect, greenplum_dialect. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb', line 145 class Dialect include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#teradata_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::TeradataDialect
Returns The Teradata dialect
Note: The following fields are mutually exclusive: teradata_dialect, bigquery_dialect, hiveql_dialect, redshift_dialect, oracle_dialect, sparksql_dialect, snowflake_dialect, netezza_dialect, azure_synapse_dialect, vertica_dialect, sql_server_dialect, postgresql_dialect, presto_dialect, mysql_dialect, db2_dialect, sqlite_dialect, greenplum_dialect. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb', line 145 class Dialect include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#vertica_dialect ⇒ ::Google::Cloud::Bigquery::Migration::V2::VerticaDialect
Returns The Vertica dialect
Note: The following fields are mutually exclusive: vertica_dialect, bigquery_dialect, hiveql_dialect, redshift_dialect, teradata_dialect, oracle_dialect, sparksql_dialect, snowflake_dialect, netezza_dialect, azure_synapse_dialect, sql_server_dialect, postgresql_dialect, presto_dialect, mysql_dialect, db2_dialect, sqlite_dialect, greenplum_dialect. If a field in that set is populated, all other fields in the set will automatically be cleared.
145 146 147 148 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb', line 145 class Dialect include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |