Class: Google::Cloud::Bigquery::Migration::V2::MigrationSubtask

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb

Overview

A subtask for a migration which carries details about the configuration of the subtask. The content of the details should not matter to the end user, but is a contract between the subtask creator and subtask worker.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Time when the subtask was created.

Returns:



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 239

class MigrationSubtask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration subtask.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The subtask is ready, i.e. it is ready for execution.
    ACTIVE = 1

    # The subtask is running, i.e. it is assigned to a worker for execution.
    RUNNING = 2

    # The subtask finished successfully.
    SUCCEEDED = 3

    # The subtask finished unsuccessfully.
    FAILED = 4

    # The subtask is paused, i.e., it will not be scheduled. If it was already
    # assigned,it might still finish but no new lease renewals will be granted.
    PAUSED = 5

    # The subtask is pending a dependency. It will be scheduled once its
    # dependencies are done.
    PENDING_DEPENDENCY = 6
  end
end

#last_update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Time when the subtask was last updated.

Returns:



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 239

class MigrationSubtask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration subtask.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The subtask is ready, i.e. it is ready for execution.
    ACTIVE = 1

    # The subtask is running, i.e. it is assigned to a worker for execution.
    RUNNING = 2

    # The subtask finished successfully.
    SUCCEEDED = 3

    # The subtask finished unsuccessfully.
    FAILED = 4

    # The subtask is paused, i.e., it will not be scheduled. If it was already
    # assigned,it might still finish but no new lease renewals will be granted.
    PAUSED = 5

    # The subtask is pending a dependency. It will be scheduled once its
    # dependencies are done.
    PENDING_DEPENDENCY = 6
  end
end

#metrics::Array<::Google::Cloud::Bigquery::Migration::V2::TimeSeries> (readonly)

Returns Output only. The metrics for the subtask.

Returns:



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 239

class MigrationSubtask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration subtask.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The subtask is ready, i.e. it is ready for execution.
    ACTIVE = 1

    # The subtask is running, i.e. it is assigned to a worker for execution.
    RUNNING = 2

    # The subtask finished successfully.
    SUCCEEDED = 3

    # The subtask finished unsuccessfully.
    FAILED = 4

    # The subtask is paused, i.e., it will not be scheduled. If it was already
    # assigned,it might still finish but no new lease renewals will be granted.
    PAUSED = 5

    # The subtask is pending a dependency. It will be scheduled once its
    # dependencies are done.
    PENDING_DEPENDENCY = 6
  end
end

#name::String (readonly)

Returns Output only. Immutable. The resource name for the migration subtask. The ID is server-generated.

Example: projects/123/locations/us/workflows/345/subtasks/678.

Returns:

  • (::String)

    Output only. Immutable. The resource name for the migration subtask. The ID is server-generated.

    Example: projects/123/locations/us/workflows/345/subtasks/678



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 239

class MigrationSubtask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration subtask.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The subtask is ready, i.e. it is ready for execution.
    ACTIVE = 1

    # The subtask is running, i.e. it is assigned to a worker for execution.
    RUNNING = 2

    # The subtask finished successfully.
    SUCCEEDED = 3

    # The subtask finished unsuccessfully.
    FAILED = 4

    # The subtask is paused, i.e., it will not be scheduled. If it was already
    # assigned,it might still finish but no new lease renewals will be granted.
    PAUSED = 5

    # The subtask is pending a dependency. It will be scheduled once its
    # dependencies are done.
    PENDING_DEPENDENCY = 6
  end
end

#processing_error::Google::Rpc::ErrorInfo (readonly)

Returns Output only. An explanation that may be populated when the task is in FAILED state.

Returns:



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 239

class MigrationSubtask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration subtask.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The subtask is ready, i.e. it is ready for execution.
    ACTIVE = 1

    # The subtask is running, i.e. it is assigned to a worker for execution.
    RUNNING = 2

    # The subtask finished successfully.
    SUCCEEDED = 3

    # The subtask finished unsuccessfully.
    FAILED = 4

    # The subtask is paused, i.e., it will not be scheduled. If it was already
    # assigned,it might still finish but no new lease renewals will be granted.
    PAUSED = 5

    # The subtask is pending a dependency. It will be scheduled once its
    # dependencies are done.
    PENDING_DEPENDENCY = 6
  end
end

#resource_error_count::Integer (readonly)

Returns Output only. The number or resources with errors. Note: This is not the total number of errors as each resource can have more than one error. This is used to indicate truncation by having a resource_error_count that is higher than the size of resource_error_details.

Returns:

  • (::Integer)

    Output only. The number or resources with errors. Note: This is not the total number of errors as each resource can have more than one error. This is used to indicate truncation by having a resource_error_count that is higher than the size of resource_error_details.



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 239

class MigrationSubtask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration subtask.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The subtask is ready, i.e. it is ready for execution.
    ACTIVE = 1

    # The subtask is running, i.e. it is assigned to a worker for execution.
    RUNNING = 2

    # The subtask finished successfully.
    SUCCEEDED = 3

    # The subtask finished unsuccessfully.
    FAILED = 4

    # The subtask is paused, i.e., it will not be scheduled. If it was already
    # assigned,it might still finish but no new lease renewals will be granted.
    PAUSED = 5

    # The subtask is pending a dependency. It will be scheduled once its
    # dependencies are done.
    PENDING_DEPENDENCY = 6
  end
end

#resource_error_details::Array<::Google::Cloud::Bigquery::Migration::V2::ResourceErrorDetail> (readonly)

Returns Output only. Provides details to errors and issues encountered while processing the subtask. Presence of error details does not mean that the subtask failed.

Returns:



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 239

class MigrationSubtask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration subtask.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The subtask is ready, i.e. it is ready for execution.
    ACTIVE = 1

    # The subtask is running, i.e. it is assigned to a worker for execution.
    RUNNING = 2

    # The subtask finished successfully.
    SUCCEEDED = 3

    # The subtask finished unsuccessfully.
    FAILED = 4

    # The subtask is paused, i.e., it will not be scheduled. If it was already
    # assigned,it might still finish but no new lease renewals will be granted.
    PAUSED = 5

    # The subtask is pending a dependency. It will be scheduled once its
    # dependencies are done.
    PENDING_DEPENDENCY = 6
  end
end

#state::Google::Cloud::Bigquery::Migration::V2::MigrationSubtask::State (readonly)

Returns Output only. The current state of the subtask.

Returns:



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 239

class MigrationSubtask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration subtask.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The subtask is ready, i.e. it is ready for execution.
    ACTIVE = 1

    # The subtask is running, i.e. it is assigned to a worker for execution.
    RUNNING = 2

    # The subtask finished successfully.
    SUCCEEDED = 3

    # The subtask finished unsuccessfully.
    FAILED = 4

    # The subtask is paused, i.e., it will not be scheduled. If it was already
    # assigned,it might still finish but no new lease renewals will be granted.
    PAUSED = 5

    # The subtask is pending a dependency. It will be scheduled once its
    # dependencies are done.
    PENDING_DEPENDENCY = 6
  end
end

#task_id::String

Returns The unique ID of the task to which this subtask belongs.

Returns:

  • (::String)

    The unique ID of the task to which this subtask belongs.



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 239

class MigrationSubtask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration subtask.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The subtask is ready, i.e. it is ready for execution.
    ACTIVE = 1

    # The subtask is running, i.e. it is assigned to a worker for execution.
    RUNNING = 2

    # The subtask finished successfully.
    SUCCEEDED = 3

    # The subtask finished unsuccessfully.
    FAILED = 4

    # The subtask is paused, i.e., it will not be scheduled. If it was already
    # assigned,it might still finish but no new lease renewals will be granted.
    PAUSED = 5

    # The subtask is pending a dependency. It will be scheduled once its
    # dependencies are done.
    PENDING_DEPENDENCY = 6
  end
end

#type::String

Returns The type of the Subtask. The migration service does not check whether this is a known type. It is up to the task creator (i.e. orchestrator or worker) to ensure it only creates subtasks for which there are compatible workers polling for Subtasks.

Returns:

  • (::String)

    The type of the Subtask. The migration service does not check whether this is a known type. It is up to the task creator (i.e. orchestrator or worker) to ensure it only creates subtasks for which there are compatible workers polling for Subtasks.



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 239

class MigrationSubtask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration subtask.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The subtask is ready, i.e. it is ready for execution.
    ACTIVE = 1

    # The subtask is running, i.e. it is assigned to a worker for execution.
    RUNNING = 2

    # The subtask finished successfully.
    SUCCEEDED = 3

    # The subtask finished unsuccessfully.
    FAILED = 4

    # The subtask is paused, i.e., it will not be scheduled. If it was already
    # assigned,it might still finish but no new lease renewals will be granted.
    PAUSED = 5

    # The subtask is pending a dependency. It will be scheduled once its
    # dependencies are done.
    PENDING_DEPENDENCY = 6
  end
end