Module: Google::Cloud::Bigquery::Migration::V2::MigrationSubtask::State
- Defined in:
- proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb
Overview
Possible states of a migration subtask.
Constant Summary collapse
- STATE_UNSPECIFIED =
The state is unspecified.
0- ACTIVE =
The subtask is ready, i.e. it is ready for execution.
1- RUNNING =
The subtask is running, i.e. it is assigned to a worker for execution.
2- SUCCEEDED =
The subtask finished successfully.
3- FAILED =
The subtask finished unsuccessfully.
4- PAUSED =
The subtask is paused, i.e., it will not be scheduled. If it was already assigned,it might still finish but no new lease renewals will be granted.
5- PENDING_DEPENDENCY =
The subtask is pending a dependency. It will be scheduled once its dependencies are done.
6