Class: Google::Cloud::Bigquery::Migration::V2::MigrationTask

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb

Overview

A single task for a migration which has details about the configuration of the task.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#assessment_task_details::Google::Cloud::Bigquery::Migration::V2::AssessmentTaskDetails

Returns Task configuration for Assessment.

Note: The following fields are mutually exclusive: assessment_task_details, translation_config_details, translation_details. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Bigquery::Migration::V2::AssessmentTaskDetails)

    Task configuration for Assessment.

    Note: The following fields are mutually exclusive: assessment_task_details, translation_config_details, translation_details. If a field in that set is populated, all other fields in the set will automatically be cleared.



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 164

class MigrationTask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration task.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The task is waiting for orchestration.
    PENDING = 1

    # The task is assigned to an orchestrator.
    ORCHESTRATING = 2

    # The task is running, i.e. its subtasks are ready for execution.
    RUNNING = 3

    # The task is paused. Assigned subtasks can continue, but no new subtasks
    # will be scheduled.
    PAUSED = 4

    # The task finished successfully.
    SUCCEEDED = 5

    # The task finished unsuccessfully.
    FAILED = 6
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Time when the task was created.

Returns:



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 164

class MigrationTask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration task.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The task is waiting for orchestration.
    PENDING = 1

    # The task is assigned to an orchestrator.
    ORCHESTRATING = 2

    # The task is running, i.e. its subtasks are ready for execution.
    RUNNING = 3

    # The task is paused. Assigned subtasks can continue, but no new subtasks
    # will be scheduled.
    PAUSED = 4

    # The task finished successfully.
    SUCCEEDED = 5

    # The task finished unsuccessfully.
    FAILED = 6
  end
end

#id::String (readonly)

Returns Output only. Immutable. The unique identifier for the migration task. The ID is server-generated.

Returns:

  • (::String)

    Output only. Immutable. The unique identifier for the migration task. The ID is server-generated.



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 164

class MigrationTask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration task.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The task is waiting for orchestration.
    PENDING = 1

    # The task is assigned to an orchestrator.
    ORCHESTRATING = 2

    # The task is running, i.e. its subtasks are ready for execution.
    RUNNING = 3

    # The task is paused. Assigned subtasks can continue, but no new subtasks
    # will be scheduled.
    PAUSED = 4

    # The task finished successfully.
    SUCCEEDED = 5

    # The task finished unsuccessfully.
    FAILED = 6
  end
end

#last_update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Time when the task was last updated.

Returns:



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 164

class MigrationTask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration task.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The task is waiting for orchestration.
    PENDING = 1

    # The task is assigned to an orchestrator.
    ORCHESTRATING = 2

    # The task is running, i.e. its subtasks are ready for execution.
    RUNNING = 3

    # The task is paused. Assigned subtasks can continue, but no new subtasks
    # will be scheduled.
    PAUSED = 4

    # The task finished successfully.
    SUCCEEDED = 5

    # The task finished unsuccessfully.
    FAILED = 6
  end
end

#metrics::Array<::Google::Cloud::Bigquery::Migration::V2::TimeSeries> (readonly)

Returns Output only. The metrics for the task.

Returns:



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 164

class MigrationTask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration task.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The task is waiting for orchestration.
    PENDING = 1

    # The task is assigned to an orchestrator.
    ORCHESTRATING = 2

    # The task is running, i.e. its subtasks are ready for execution.
    RUNNING = 3

    # The task is paused. Assigned subtasks can continue, but no new subtasks
    # will be scheduled.
    PAUSED = 4

    # The task finished successfully.
    SUCCEEDED = 5

    # The task finished unsuccessfully.
    FAILED = 6
  end
end

#processing_error::Google::Rpc::ErrorInfo (readonly)

Returns Output only. An explanation that may be populated when the task is in FAILED state.

Returns:



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 164

class MigrationTask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration task.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The task is waiting for orchestration.
    PENDING = 1

    # The task is assigned to an orchestrator.
    ORCHESTRATING = 2

    # The task is running, i.e. its subtasks are ready for execution.
    RUNNING = 3

    # The task is paused. Assigned subtasks can continue, but no new subtasks
    # will be scheduled.
    PAUSED = 4

    # The task finished successfully.
    SUCCEEDED = 5

    # The task finished unsuccessfully.
    FAILED = 6
  end
end

#resource_error_count::Integer (readonly)

Returns Output only. The number or resources with errors. Note: This is not the total number of errors as each resource can have more than one error. This is used to indicate truncation by having a resource_error_count that is higher than the size of resource_error_details.

Returns:

  • (::Integer)

    Output only. The number or resources with errors. Note: This is not the total number of errors as each resource can have more than one error. This is used to indicate truncation by having a resource_error_count that is higher than the size of resource_error_details.



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 164

class MigrationTask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration task.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The task is waiting for orchestration.
    PENDING = 1

    # The task is assigned to an orchestrator.
    ORCHESTRATING = 2

    # The task is running, i.e. its subtasks are ready for execution.
    RUNNING = 3

    # The task is paused. Assigned subtasks can continue, but no new subtasks
    # will be scheduled.
    PAUSED = 4

    # The task finished successfully.
    SUCCEEDED = 5

    # The task finished unsuccessfully.
    FAILED = 6
  end
end

#resource_error_details::Array<::Google::Cloud::Bigquery::Migration::V2::ResourceErrorDetail> (readonly)

Returns Output only. Provides details to errors and issues encountered while processing the task. Presence of error details does not mean that the task failed.

Returns:



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 164

class MigrationTask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration task.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The task is waiting for orchestration.
    PENDING = 1

    # The task is assigned to an orchestrator.
    ORCHESTRATING = 2

    # The task is running, i.e. its subtasks are ready for execution.
    RUNNING = 3

    # The task is paused. Assigned subtasks can continue, but no new subtasks
    # will be scheduled.
    PAUSED = 4

    # The task finished successfully.
    SUCCEEDED = 5

    # The task finished unsuccessfully.
    FAILED = 6
  end
end

#state::Google::Cloud::Bigquery::Migration::V2::MigrationTask::State (readonly)

Returns Output only. The current state of the task.

Returns:



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 164

class MigrationTask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration task.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The task is waiting for orchestration.
    PENDING = 1

    # The task is assigned to an orchestrator.
    ORCHESTRATING = 2

    # The task is running, i.e. its subtasks are ready for execution.
    RUNNING = 3

    # The task is paused. Assigned subtasks can continue, but no new subtasks
    # will be scheduled.
    PAUSED = 4

    # The task finished successfully.
    SUCCEEDED = 5

    # The task finished unsuccessfully.
    FAILED = 6
  end
end

#task_result::Google::Cloud::Bigquery::Migration::V2::MigrationTaskResult (readonly)

Returns Output only. The result of the task.

Returns:



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 164

class MigrationTask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration task.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The task is waiting for orchestration.
    PENDING = 1

    # The task is assigned to an orchestrator.
    ORCHESTRATING = 2

    # The task is running, i.e. its subtasks are ready for execution.
    RUNNING = 3

    # The task is paused. Assigned subtasks can continue, but no new subtasks
    # will be scheduled.
    PAUSED = 4

    # The task finished successfully.
    SUCCEEDED = 5

    # The task finished unsuccessfully.
    FAILED = 6
  end
end

#total_processing_error_count::Integer (readonly)

Returns Output only. Count of all the processing errors in this task and its subtasks.

Returns:

  • (::Integer)

    Output only. Count of all the processing errors in this task and its subtasks.



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 164

class MigrationTask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration task.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The task is waiting for orchestration.
    PENDING = 1

    # The task is assigned to an orchestrator.
    ORCHESTRATING = 2

    # The task is running, i.e. its subtasks are ready for execution.
    RUNNING = 3

    # The task is paused. Assigned subtasks can continue, but no new subtasks
    # will be scheduled.
    PAUSED = 4

    # The task finished successfully.
    SUCCEEDED = 5

    # The task finished unsuccessfully.
    FAILED = 6
  end
end

#total_resource_error_count::Integer (readonly)

Returns Output only. Count of all the resource errors in this task and its subtasks.

Returns:

  • (::Integer)

    Output only. Count of all the resource errors in this task and its subtasks.



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 164

class MigrationTask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration task.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The task is waiting for orchestration.
    PENDING = 1

    # The task is assigned to an orchestrator.
    ORCHESTRATING = 2

    # The task is running, i.e. its subtasks are ready for execution.
    RUNNING = 3

    # The task is paused. Assigned subtasks can continue, but no new subtasks
    # will be scheduled.
    PAUSED = 4

    # The task finished successfully.
    SUCCEEDED = 5

    # The task finished unsuccessfully.
    FAILED = 6
  end
end

#translation_config_details::Google::Cloud::Bigquery::Migration::V2::TranslationConfigDetails

Returns Task configuration for CW Batch/Offline SQL Translation.

Note: The following fields are mutually exclusive: translation_config_details, assessment_task_details, translation_details. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Bigquery::Migration::V2::TranslationConfigDetails)

    Task configuration for CW Batch/Offline SQL Translation.

    Note: The following fields are mutually exclusive: translation_config_details, assessment_task_details, translation_details. If a field in that set is populated, all other fields in the set will automatically be cleared.



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 164

class MigrationTask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration task.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The task is waiting for orchestration.
    PENDING = 1

    # The task is assigned to an orchestrator.
    ORCHESTRATING = 2

    # The task is running, i.e. its subtasks are ready for execution.
    RUNNING = 3

    # The task is paused. Assigned subtasks can continue, but no new subtasks
    # will be scheduled.
    PAUSED = 4

    # The task finished successfully.
    SUCCEEDED = 5

    # The task finished unsuccessfully.
    FAILED = 6
  end
end

#translation_details::Google::Cloud::Bigquery::Migration::V2::TranslationDetails

Returns Task details for unified SQL Translation.

Note: The following fields are mutually exclusive: translation_details, assessment_task_details, translation_config_details. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Bigquery::Migration::V2::TranslationDetails)

    Task details for unified SQL Translation.

    Note: The following fields are mutually exclusive: translation_details, assessment_task_details, translation_config_details. If a field in that set is populated, all other fields in the set will automatically be cleared.



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 164

class MigrationTask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration task.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The task is waiting for orchestration.
    PENDING = 1

    # The task is assigned to an orchestrator.
    ORCHESTRATING = 2

    # The task is running, i.e. its subtasks are ready for execution.
    RUNNING = 3

    # The task is paused. Assigned subtasks can continue, but no new subtasks
    # will be scheduled.
    PAUSED = 4

    # The task finished successfully.
    SUCCEEDED = 5

    # The task finished unsuccessfully.
    FAILED = 6
  end
end

#type::String

Returns The type of the task. This must be one of the supported task types.

Assessment:

  • Assessment_Hive - Assessment for Hive.
  • Assessment_Redshift - Assessment for Redshift.
  • Assessment_Snowflake - Assessment for Snowflake.
  • Assessment_Teradata_v2 - Assessment for Teradata.
  • Assessment_Oracle - Assessment for Oracle.
  • Assessment_Hadoop - Assessment for Hadoop.
  • Assessment_Informatica - Assessment for Informatica.

Translation: See Supported Task Types for a list of supported task types.

Returns:

  • (::String)

    The type of the task. This must be one of the supported task types.

    Assessment:

    • Assessment_Hive - Assessment for Hive.
    • Assessment_Redshift - Assessment for Redshift.
    • Assessment_Snowflake - Assessment for Snowflake.
    • Assessment_Teradata_v2 - Assessment for Teradata.
    • Assessment_Oracle - Assessment for Oracle.
    • Assessment_Hadoop - Assessment for Hadoop.
    • Assessment_Informatica - Assessment for Informatica.

    Translation: See Supported Task Types for a list of supported task types.



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/bigquery/migration/v2/migration_entities.rb', line 164

class MigrationTask
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of a migration task.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The task is waiting for orchestration.
    PENDING = 1

    # The task is assigned to an orchestrator.
    ORCHESTRATING = 2

    # The task is running, i.e. its subtasks are ready for execution.
    RUNNING = 3

    # The task is paused. Assigned subtasks can continue, but no new subtasks
    # will be scheduled.
    PAUSED = 4

    # The task finished successfully.
    SUCCEEDED = 5

    # The task finished unsuccessfully.
    FAILED = 6
  end
end