Class: Google::Cloud::Bigquery::Migration::V2::NameMappingKey
- Inherits:
-
Object
- Object
- Google::Cloud::Bigquery::Migration::V2::NameMappingKey
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb
Overview
The potential components of a full name mapping that will be mapped during translation in the source data warehouse.
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#attribute ⇒ ::String
The attribute name (BigQuery column equivalent in the source data warehouse).
-
#database ⇒ ::String
The database name (BigQuery project ID equivalent in the source data warehouse).
-
#relation ⇒ ::String
The relation name (BigQuery table or view equivalent in the source data warehouse).
-
#schema ⇒ ::String
The schema name (BigQuery dataset equivalent in the source data warehouse).
-
#type ⇒ ::Google::Cloud::Bigquery::Migration::V2::NameMappingKey::Type
The type of object that is being mapped.
Instance Attribute Details
#attribute ⇒ ::String
Returns The attribute name (BigQuery column equivalent in the source data warehouse).
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb', line 310 class NameMappingKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the object that is being mapped. module Type # Unspecified name mapping type. TYPE_UNSPECIFIED = 0 # The object being mapped is a database. DATABASE = 1 # The object being mapped is a schema. SCHEMA = 2 # The object being mapped is a relation. RELATION = 3 # The object being mapped is an attribute. ATTRIBUTE = 4 # The object being mapped is a relation alias. RELATION_ALIAS = 5 # The object being mapped is a an attribute alias. ATTRIBUTE_ALIAS = 6 # The object being mapped is a function. FUNCTION = 7 end end |
#database ⇒ ::String
Returns The database name (BigQuery project ID equivalent in the source data warehouse).
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb', line 310 class NameMappingKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the object that is being mapped. module Type # Unspecified name mapping type. TYPE_UNSPECIFIED = 0 # The object being mapped is a database. DATABASE = 1 # The object being mapped is a schema. SCHEMA = 2 # The object being mapped is a relation. RELATION = 3 # The object being mapped is an attribute. ATTRIBUTE = 4 # The object being mapped is a relation alias. RELATION_ALIAS = 5 # The object being mapped is a an attribute alias. ATTRIBUTE_ALIAS = 6 # The object being mapped is a function. FUNCTION = 7 end end |
#relation ⇒ ::String
Returns The relation name (BigQuery table or view equivalent in the source data warehouse).
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb', line 310 class NameMappingKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the object that is being mapped. module Type # Unspecified name mapping type. TYPE_UNSPECIFIED = 0 # The object being mapped is a database. DATABASE = 1 # The object being mapped is a schema. SCHEMA = 2 # The object being mapped is a relation. RELATION = 3 # The object being mapped is an attribute. ATTRIBUTE = 4 # The object being mapped is a relation alias. RELATION_ALIAS = 5 # The object being mapped is a an attribute alias. ATTRIBUTE_ALIAS = 6 # The object being mapped is a function. FUNCTION = 7 end end |
#schema ⇒ ::String
Returns The schema name (BigQuery dataset equivalent in the source data warehouse).
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb', line 310 class NameMappingKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the object that is being mapped. module Type # Unspecified name mapping type. TYPE_UNSPECIFIED = 0 # The object being mapped is a database. DATABASE = 1 # The object being mapped is a schema. SCHEMA = 2 # The object being mapped is a relation. RELATION = 3 # The object being mapped is an attribute. ATTRIBUTE = 4 # The object being mapped is a relation alias. RELATION_ALIAS = 5 # The object being mapped is a an attribute alias. ATTRIBUTE_ALIAS = 6 # The object being mapped is a function. FUNCTION = 7 end end |
#type ⇒ ::Google::Cloud::Bigquery::Migration::V2::NameMappingKey::Type
Returns The type of object that is being mapped.
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_config.rb', line 310 class NameMappingKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the object that is being mapped. module Type # Unspecified name mapping type. TYPE_UNSPECIFIED = 0 # The object being mapped is a database. DATABASE = 1 # The object being mapped is a schema. SCHEMA = 2 # The object being mapped is a relation. RELATION = 3 # The object being mapped is an attribute. ATTRIBUTE = 4 # The object being mapped is a relation alias. RELATION_ALIAS = 5 # The object being mapped is a an attribute alias. ATTRIBUTE_ALIAS = 6 # The object being mapped is a function. FUNCTION = 7 end end |