Class: Google::Cloud::Bigquery::Migration::V2::SourceSpec
- Inherits:
-
Object
- Object
- Google::Cloud::Bigquery::Migration::V2::SourceSpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/bigquery/migration/v2/translation_details.rb
Overview
Represents one path to the location that holds source data.
Instance Attribute Summary collapse
-
#base_uri ⇒ ::String
The base URI for all files to be read in as sources for translation.
-
#encoding ⇒ ::String
Optional.
-
#gcs_file_path ⇒ ::String
The path to a single source file in Cloud Storage.
-
#literal ⇒ ::Google::Cloud::Bigquery::Migration::V2::Literal
Source literal.
Instance Attribute Details
#base_uri ⇒ ::String
Returns The base URI for all files to be read in as sources for translation.
Note: The following fields are mutually exclusive: base_uri, literal, gcs_file_path. If a field in that set is populated, all other fields in the set will automatically be cleared.
131 132 133 134 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_details.rb', line 131 class SourceSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#encoding ⇒ ::String
Returns Optional. The optional field to specify the encoding of the sql bytes.
131 132 133 134 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_details.rb', line 131 class SourceSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gcs_file_path ⇒ ::String
Returns The path to a single source file in Cloud Storage.
Note: The following fields are mutually exclusive: gcs_file_path, base_uri, literal. If a field in that set is populated, all other fields in the set will automatically be cleared.
131 132 133 134 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_details.rb', line 131 class SourceSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#literal ⇒ ::Google::Cloud::Bigquery::Migration::V2::Literal
Returns Source literal.
Note: The following fields are mutually exclusive: literal, base_uri, gcs_file_path. If a field in that set is populated, all other fields in the set will automatically be cleared.
131 132 133 134 |
# File 'proto_docs/google/cloud/bigquery/migration/v2/translation_details.rb', line 131 class SourceSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |